@@ -1,10 +1,11 @@
 import argparse
 import copy
+import datetime
 import json
 import logging
+import re
 import time
 import uuid
-import re
 from collections import OrderedDict
 
 from wzdx.tools import date_tools, polygon_tools, wzdx_translator
@@ -89,19 +90,8 @@ def generate_raw_messages(message_string):
 
     separated_messages = expand_event_directions(msg)
     for indiv_msg in separated_messages:
-        is_incident_msg, is_wz = is_incident(indiv_msg)
-        if is_incident_msg and is_wz:
-            messages.append(indiv_msg)
-        elif not is_incident_msg:
-            messages.append(indiv_msg)
-        else:
-            id = indiv_msg.get('properties', {}).get('id')
-            dir = indiv_msg.get('properties', {}).get('direction')
-            logging.warning(
-                f"Ignoring non-work zone incident: {id}_{dir}")
-            # Don't process non-wz incidents
-            pass
-
+        # add any validation or checks here
+        messages.append(indiv_msg)
     return messages
 
 
@@ -130,9 +120,16 @@ def expand_event_directions(message):
         return [message]
 
 
-def generate_rtdh_standard_message_from_raw_single(obj, is_incident=False):
+def generate_rtdh_standard_message_from_raw_single(obj):
+    is_incident_msg, is_wz = is_incident(obj)
+    if is_incident_msg and not is_wz:
+        id = obj.get('properties', {}).get('id')
+        dir = obj.get('properties', {}).get('direction')
+        logging.warning(
+            f"Ignoring non-work zone incident: {id}_{dir}")
+        return {}
     pd = PathDict(obj)
-    standard_message = create_rtdh_standard_msg(pd, is_incident)
+    standard_message = create_rtdh_standard_msg(pd, is_incident_msg)
     return standard_message
 
 
@@ -360,6 +357,9 @@ def create_rtdh_standard_msg(pd, isIncident):
                         date_tools.parse_datetime_from_iso_string)
     end_date = pd.get("properties/clearTime",
                       date_tools.parse_datetime_from_iso_string)
+    if not end_date:
+        # Since there is no end date, assume still active, set end date in future
+        end_date = datetime.datetime.utcnow() + datetime.timedelta(hours=24)
 
     event_type, types_of_work = map_event_type(
         pd.get("properties/type", default=""))
